@@ -4,10 +4,21 @@
 
 #import <dispatch/dispatch.h>
 
+/*
+ * The definitions below can cause warnings when using
+ * -Wunguarded-availability, but those warnings are harmless
+ * because the functions are inline functions and hence will
+ * be available on all macOS versions once compiled.
+ */
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wunguarded-availability"
+
 static PyObjC_function_map function_map[] = {
     {"dispatch_get_main_queue", (PyObjC_Function_Pointer)&dispatch_get_main_queue},
     {0, 0}};
 
+#pragma clang diagnostic pop
+
 static PyMethodDef mod_methods[] = {
     {0, 0, 0, 0} /* sentinel */
 };
